﻿using System;
using MiniBuss;
using System.Configuration;

namespace Receiver
{
    /// <summary>
    /// This receiver is using local message classes which looks the same as the ones sent by the publisher.
    /// Namespace doesn't matter, just use the same class and property names.
    /// 
    /// It may also share message classes with the sender for convenience.
    /// </summary>
    class Program
    {
        static void Main()
        {
            //读取队列（接收目的）
            var bus = new ServiceBus { LocalEndpoint = ConfigurationManager.AppSettings["LocalEndpoint"].ToString() };

            bus.RegisterMessageHandler<HelloCommand>(command =>
            {
                Console.ForegroundColor = ConsoleColor.Green;
                Console.WriteLine(DateTime.Now+ ":Receiver From:  " + command.Guid + ", Number: " + command.Number);

                bus.Reply(command, new HelloResponse { Guid = command.Guid, Message = "Hello back!" });
            });

            bus.Start();

            Console.WriteLine("Waiting for commands, press ENTER to exit");
            Console.ReadLine();
        }
    }

    public class HelloResponse
    {
        public Guid Guid { get; set; }
        public string Message { get; set; }
    }

    public class HelloCommand
    {
        public Guid Guid { get; set; }
        public string Message { get; set; }
        public int Number { get; set; }
    }

}
