﻿using System;
using System.Threading.Tasks;
using Messages;
using MiniBuss;
using System.Threading;
using System.Configuration;

namespace Sender
{
    class Program
    {
        static void Main()
        {
            //读取队列（接收目的）
            var bus = new ServiceBus { LocalEndpoint = ConfigurationManager.AppSettings["LocalEndpoint"].ToString() };
            //发送队列(发送目的)
            bus.RegisterMessageEndpoint<HelloCommand>(ConfigurationManager.AppSettings["TargetEndpoint"].ToString());
            bus.RegisterMessageHandler<HelloResponse>(reply =>
                    {
                        Console.ForegroundColor = ConsoleColor.Cyan;
                        Console.WriteLine(DateTime.Now+":Reply from receiver: " + reply.Guid.ToString());
                    });

            bus.Start();
            Task.Factory.StartNew(() => SendThread(bus), TaskCreationOptions.LongRunning);
            Console.WriteLine("Working, press ENTER to exit");
            Console.ReadLine();
        }

        private static void SendThread(IServiceBus bus)
        {
            var random = new Random();
            int i = 1;
            while(true)
            {
                System.Guid gid = Guid.NewGuid();
                Console.ForegroundColor = ConsoleColor.Green;
                Console.WriteLine(i.ToString()+"......Sending command with " + gid);                
                bus.Send(new HelloCommand { Guid = gid, Message = "Hello", Number = random.Next() });
                Thread.Sleep(100);
                i++;
            }
            Console.WriteLine("Done!");
        }
    }
}
